pub struct MaxDecimalPlaces { /* private fields */ }Expand description
MaxDecimalPlaces
Enforces an upper bound on fractional precision for Decimal values.
Values with a larger scale than target are rejected.
Implementations