pub struct EntityMigration { /* private fields */ }Expand description
One immediate-predecessor transition for a current entity declaration.
Implementations
Sourceimpl EntityMigration
impl EntityMigration
Sourcepub fn try_new(
entity: EntitySourceKey,
from: DeclaredEntityVersion,
from_name: Option<EntitySourceKey>,
renames: Vec<SchemaMigrationRename>,
transforms: Vec<SchemaMigrationTransform>,
) -> Result<EntityMigration, SchemaContractError>
pub fn try_new( entity: EntitySourceKey, from: DeclaredEntityVersion, from_name: Option<EntitySourceKey>, renames: Vec<SchemaMigrationRename>, transforms: Vec<SchemaMigrationTransform>, ) -> Result<EntityMigration, SchemaContractError>
Construct and canonicalize one entity transition.
Errors
Returns a typed migration error for an empty transition, a no-op entity rename, duplicate rename ownership, duplicate transform target, or invalid transform.
Sourcepub const fn entity(&self) -> &EntitySourceKey
pub const fn entity(&self) -> &EntitySourceKey
Borrow the current target entity key.
Sourcepub const fn from(&self) -> DeclaredEntityVersion
pub const fn from(&self) -> DeclaredEntityVersion
Return the accepted-before declared entity version.
Sourcepub const fn from_name(&self) -> Option<&EntitySourceKey>
pub const fn from_name(&self) -> Option<&EntitySourceKey>
Borrow an optional accepted-before entity name.
Sourcepub fn renames(&self) -> &[SchemaMigrationRename]
pub fn renames(&self) -> &[SchemaMigrationRename]
Borrow canonical rename operations.
Sourcepub fn transforms(&self) -> &[SchemaMigrationTransform]
pub fn transforms(&self) -> &[SchemaMigrationTransform]
Borrow canonical historical transforms.