pub struct EnumTypeFragment { /* private fields */ }Expand description
Named enum-type definition.
Implementations
Sourceimpl EnumTypeFragment
impl EnumTypeFragment
Sourcepub fn try_new(
name: SchemaName,
variants: Vec<EnumVariantFragment>,
) -> Result<EnumTypeFragment, SchemaContractError>
pub fn try_new( name: SchemaName, variants: Vec<EnumVariantFragment>, ) -> Result<EnumTypeFragment, SchemaContractError>
Construct and canonicalize an enum definition.
Errors
Returns a typed contract error for empty, oversized, or duplicate variants.
Sourcepub const fn source_key(&self) -> &TypeSourceKey
pub const fn source_key(&self) -> &TypeSourceKey
Borrow the typed proposal key derived from the current enum name.
Sourcepub const fn name(&self) -> &SchemaName
pub const fn name(&self) -> &SchemaName
Borrow the current enum name.
Sourcepub fn variants(&self) -> &[EnumVariantFragment]
pub fn variants(&self) -> &[EnumVariantFragment]
Borrow canonical enum variants.