pub struct ScalarMetadata { /* private fields */ }Expand description
ScalarMetadata
Capability metadata shared across schema/core layers.
Implementations
Sourceimpl ScalarMetadata
impl ScalarMetadata
Sourcepub const fn family(self) -> ScalarCoercionFamily
pub const fn family(self) -> ScalarCoercionFamily
Return coercion routing family for this scalar metadata entry.
Sourcepub const fn is_numeric_value(self) -> bool
pub const fn is_numeric_value(self) -> bool
Return whether this scalar participates in numeric-valued classification.
Sourcepub const fn supports_numeric_coercion(self) -> bool
pub const fn supports_numeric_coercion(self) -> bool
Return whether this scalar supports numeric widening coercion.
Sourcepub const fn supports_arithmetic(self) -> bool
pub const fn supports_arithmetic(self) -> bool
Return whether this scalar supports arithmetic trait derivation.
Sourcepub const fn supports_equality(self) -> bool
pub const fn supports_equality(self) -> bool
Return whether this scalar supports equality predicates.
Sourcepub const fn supports_ordering(self) -> bool
pub const fn supports_ordering(self) -> bool
Return whether this scalar supports ordering predicates.
Sourcepub const fn is_keyable(self) -> bool
pub const fn is_keyable(self) -> bool
Return whether this scalar is keyable at query/schema level.
Sourcepub const fn is_primary_key_component_encodable(self) -> bool
pub const fn is_primary_key_component_encodable(self) -> bool
Return whether this scalar can be encoded as a storage key.