validate

Function validate 

pub fn validate(node: &dyn Visitable) -> Result<(), VisitorError>
validate

Validate a visitable tree, collecting issues by path.

Validation is non-failing at the traversal level. All validation issues are collected and returned to the caller, which may choose how to interpret them.

Errors

Returns VisitorError when one or more validators report an issue.