pub struct CallbackContext<'a> { /* private fields */ }Expand description
Visitor context that binds unowned issues to one typed callback identity.
Nested callback contexts preserve the innermost identity, allowing a declared normalizer or validator to override its generated traversal hook.
Implementations
Sourceimpl<'a> CallbackContext<'a>
impl<'a> CallbackContext<'a>
Sourcepub fn new(ctx: &'a mut dyn VisitorContext, callback: CallbackIdentity) -> Self
pub fn new(ctx: &'a mut dyn VisitorContext, callback: CallbackIdentity) -> Self
Bind subsequent issues to callback unless already more specifically
identified by a nested callback context.