pub struct CallbackIdentity { /* private fields */ }Expand description
Typed identity of the callback that reported an application issue.
Implementations
Sourceimpl CallbackIdentity
impl CallbackIdentity
Sourcepub const fn new(kind: CallbackKind, type_path: &'static str) -> Self
pub const fn new(kind: CallbackKind, type_path: &'static str) -> Self
Construct an identity from its callback class and concrete Rust type.
Sourcepub const fn kind(&self) -> CallbackKind
pub const fn kind(&self) -> CallbackKind
Return the callback class.