Enums
- Build
Error - BuildError
Functions
- generate
- Generate private canister actor code for the given authored schema path.
- get_
schema - Read the immutable global schema after validating and sealing it.
- register_
node - Register one constructor-produced declaration in the collecting graph.