pub fn normalize(node: &mut dyn Visitable) -> Result<(), VisitorError>Expand description
normalize
Run the normalizer visitor over a mutable visitable tree.
Traversal visits the complete value tree and aggregates any reported issues
into the returned VisitorError.
Errors
Returns VisitorError when one or more normalizers report an issue.