SourceRuleOperation

Enum SourceRuleOperation 

pub enum SourceRuleOperation {
    LengthRangeInclusive {
        min: u64,
        max: u64,
    },
    MultipleOf {
        divisor: ScalarLiteral,
    },
    NumericMaximumInclusive {
        value: ScalarLiteral,
    },
    NumericMinimumInclusive {
        value: ScalarLiteral,
    },
    NumericRangeInclusive {
        min: ScalarLiteral,
        max: ScalarLiteral,
    },
}
One closed durable operation applied to every selected nominal value.

Variants



LengthRangeInclusive

Inclusive Unicode-scalar, octet, or collection-cardinality range.

Fields

min: u64

Inclusive minimum length.

max: u64

Inclusive maximum length.



MultipleOf

Exact nonzero integer or fixed-scale decimal divisor.

Fields

divisor: ScalarLiteral

Exact divisor admitted against the target kind.



NumericMaximumInclusive

Inclusive upper bound for one exact numeric kind.

Fields

value: ScalarLiteral

Exact upper-bound literal.



NumericMinimumInclusive

Inclusive lower bound for one exact numeric kind.

Fields

value: ScalarLiteral

Exact lower-bound literal.



NumericRangeInclusive

Inclusive lower and upper bounds for one exact numeric kind.

Fields

min: ScalarLiteral

Exact lower-bound literal.

max: ScalarLiteral

Exact upper-bound literal.