pub struct EntityFragment { /* private fields */ }Expand description
Store-free logical entity definition.
Implementations
Sourceimpl EntityFragment
impl EntityFragment
Sourcepub fn try_new(
name: SchemaName,
version: DeclaredEntityVersion,
fields: Vec<FieldFragment>,
primary_key: Vec<FieldSourceKey>,
indexes: Vec<IndexFragment>,
relations: Vec<RelationFragment>,
constraints: Vec<ConstraintFragment>,
) -> Result<EntityFragment, SchemaContractError>
pub fn try_new( name: SchemaName, version: DeclaredEntityVersion, fields: Vec<FieldFragment>, primary_key: Vec<FieldSourceKey>, indexes: Vec<IndexFragment>, relations: Vec<RelationFragment>, constraints: Vec<ConstraintFragment>, ) -> Result<EntityFragment, SchemaContractError>
Construct and canonicalize one entity definition.
Errors
Returns a typed contract error for collection overflow, duplicate source keys, malformed policy, expression, or primary-key references.
Sourcepub const fn source_key(&self) -> &EntitySourceKey
pub const fn source_key(&self) -> &EntitySourceKey
Borrow the typed proposal key derived from the current entity name.
Sourcepub const fn name(&self) -> &SchemaName
pub const fn name(&self) -> &SchemaName
Borrow the current entity name.
Sourcepub const fn version(&self) -> DeclaredEntityVersion
pub const fn version(&self) -> DeclaredEntityVersion
Return the application-declared current entity version.
Sourcepub fn fields(&self) -> &[FieldFragment]
pub fn fields(&self) -> &[FieldFragment]
Borrow canonical field definitions.
Sourcepub fn primary_key(&self) -> &[FieldSourceKey]
pub fn primary_key(&self) -> &[FieldSourceKey]
Borrow ordered primary-key fields.
Sourcepub fn indexes(&self) -> &[IndexFragment]
pub fn indexes(&self) -> &[IndexFragment]
Borrow canonical secondary-index definitions.
Sourcepub fn relations(&self) -> &[RelationFragment]
pub fn relations(&self) -> &[RelationFragment]
Borrow canonical relation definitions.
Sourcepub fn constraints(&self) -> &[ConstraintFragment]
pub fn constraints(&self) -> &[ConstraintFragment]
Borrow canonical source constraint definitions.